@@ -1934,7 +1934,7 @@ mod tests {
             let cert_read = certs_read.iter().next().expect("have one")
                 .to_cert().expect("valid");
 
-            assert!(cert_read.keys().any(|k| k.fingerprint() == fpr));
+            assert!(cert_read.keys().any(|k| k.key().fingerprint() == fpr));
         }
 
         // Test Store::lookup_by_userid.
@@ -1976,7 +1976,7 @@ mod tests {
 
         for cert in roughly_a_thousand_certs() {
             certs_fpr.push(cert.fingerprint());
-            subkeys_fpr.extend(cert.keys().subkeys().map(|ka| ka.fingerprint()));
+            subkeys_fpr.extend(cert.keys().subkeys().map(|ka| ka.key().fingerprint()));
             userids.push(cert.userids().next().unwrap().userid());
 
             let mut bytes = Vec::new();
@@ -2043,7 +2043,7 @@ mod tests {
                     for cert in source_certs.iter() {
                         eprint!("{}", tid);
                         certs_fpr.push(cert.fingerprint());
-                        subkeys_fpr.extend(cert.keys().subkeys().map(|ka| ka.fingerprint()));
+                        subkeys_fpr.extend(cert.keys().subkeys().map(|ka| ka.key().fingerprint()));
                         userids.push(cert.userids().next().unwrap().userid());
 
                         certd.update(Arc::new(cert.clone().into()))
@@ -2110,15 +2110,15 @@ mod tests {
             let primary = i == 0;
 
             if primary {
-                let d = CertD::open(p)?.lookup_by_cert(&k.fingerprint().into())?;
+                let d = CertD::open(p)?.lookup_by_cert(&k.key().fingerprint().into())?;
                 assert_eq!(&c, d[0].to_cert()?);
-                let d = CertD::open(p)?.lookup_by_cert(&k.keyid().into())?;
+                let d = CertD::open(p)?.lookup_by_cert(&k.key().keyid().into())?;
                 assert_eq!(&c, d[0].to_cert()?);
             }
 
-            let d = CertD::open(p)?.lookup_by_cert_or_subkey(&k.fingerprint().into())?;
+            let d = CertD::open(p)?.lookup_by_cert_or_subkey(&k.key().fingerprint().into())?;
             assert_eq!(&c, d[0].to_cert()?);
-            let d = CertD::open(p)?.lookup_by_cert_or_subkey(&k.keyid().into())?;
+            let d = CertD::open(p)?.lookup_by_cert_or_subkey(&k.key().keyid().into())?;
             assert_eq!(&c, d[0].to_cert()?);
         }
 
@@ -2129,10 +2129,10 @@ mod tests {
                     .set_anchor_end(true)
                     .set_email(false)
                     .set_ignore_case(false),
-                &String::from_utf8(u.value().to_vec())?)?;
+                &String::from_utf8(u.userid().value().to_vec())?)?;
             assert_eq!(&c, d[0].to_cert()?);
 
-            if let Ok(Some(e)) = u.email2() {
+            if let Ok(Some(e)) = u.userid().email() {
                 let d = CertD::open(p)?.select_userid(
                     UserIDQueryParams::new()
                         .set_anchor_start(true)
@@ -2143,7 +2143,7 @@ mod tests {
                 assert_eq!(&c, d[0].to_cert()?);
             }
 
-            if let Ok(Some(n)) = u.name2() {
+            if let Ok(Some(n)) = u.userid().name() {
                 let d = CertD::open(p)?.select_userid(
                     UserIDQueryParams::new()
                         .set_anchor_start(true)
