@@ -210,7 +210,7 @@ impl<'a> CertD<'a> {
     ///
     /// // Pretend the following certificate was fetched from keys.openpgp.org.
     /// let alice_userid = "<alice@example.org>";
-    /// let (alice, _rev) = CertBuilder::general_purpose(None, Some(alice_userid))
+    /// let (alice, _rev) = CertBuilder::general_purpose(Some(alice_userid))
     ///     .generate()?;
     ///
     /// // Certify the binding using the shadow CA.
@@ -230,7 +230,7 @@ impl<'a> CertD<'a> {
     /// let alice = alice.insert_packets([
     ///     Packet::from(UserID::from(alice_userid)),
     ///     Packet::from(sig),
-    /// ])?;
+    /// ])?.0;
     ///
     /// certd.update(Arc::new(LazyCert::from(alice)));
     /// # Ok(()) }
@@ -501,7 +501,7 @@ impl<'a> CertD<'a> {
             ca = ca.clone().insert_packets([
                 Packet::from(userid.clone()),
                 Packet::from(sig),
-            ])?;
+            ])?.0;
 
             Ok(())
         };
@@ -849,7 +849,7 @@ impl<'a> CertD<'a> {
     {
         // Sanity-check the address.
         let u = UserID::from_address(
-            "Autocrypt Gossip from".into(), None, addr)?;
+            "Autocrypt Gossip from", None, addr)?;
 
         self.shadow_ca(
             &format!("shadow_of_{:x}", cert.fingerprint()),
