@@ -414,11 +414,11 @@ impl Pep {
 
         let a_email = a_userid
             .email_normalized()
-            .or_else(|_| a_userid.uri2().map(|o| o.map(Into::into)))
+            .or_else(|_| a_userid.uri().map(|o| o.map(Into::into)))
             .ok();
         let b_email = b_userid
             .email_normalized()
-            .or_else(|_| b_userid.uri2().map(|o| o.map(Into::into)))
+            .or_else(|_| b_userid.uri().map(|o| o.map(Into::into)))
             .ok();
 
         match (a_email, b_email) {
@@ -480,7 +480,7 @@ impl Pep {
     /// Like [`Store::certs`], but only returns certificates with
     /// private key material.
     pub fn tsks<'b>(&'b self)
-        -> Box<dyn Iterator<Item=Arc<LazyCert>> + 'b>
+        -> Box<dyn Iterator<Item=Arc<LazyCert<'b>>> + 'b>
     {
         tracer!(TRACE, "Pep::tsks");
 
@@ -825,11 +825,11 @@ impl<'a> StoreUpdate<'a> for Pep {
             for (i, ka) in merged.keys().enumerate() {
                 t!("  {}key: {} ({} secret key material)",
                    if i == 0 { "primary " } else { "sub" },
-                   ka.keyid(),
-                   if ka.has_secret() { "has" } else { "no" });
+                   ka.key().keyid(),
+                   if ka.key().has_secret() { "has" } else { "no" });
                 wrap_err!(
                     stmt.execute(
-                        params![ka.keyid().to_hex(), fpr.to_hex()]),
+                        params![ka.key().keyid().to_hex(), fpr.to_hex()]),
                     UnknownDbError,
                     "Executing cert save insert subkeys")?;
             }
@@ -840,9 +840,9 @@ impl<'a> StoreUpdate<'a> for Pep {
             let mut stmt = Self::cert_save_insert_userids_stmt(&tx)?;
 
             for ua in merged.userids() {
-                let uid = if let Ok(Some(email)) = ua.email_normalized() {
+                let uid = if let Ok(Some(email)) = ua.userid().email_normalized() {
                     email
-                } else if let Ok(Some(uri)) = ua.uri2() {
+                } else if let Ok(Some(uri)) = ua.userid().uri() {
                     uri.to_string()
                 } else {
                     continue;
